utils::globalVariables(
  c(
    "dis",
    "iter",
    "method",
    "sp",
    "se",
    "color",
    "shape",
    "value",
    "group",
    "color_col",
    "x",
    "label",
    "fpr",
    "tpr",
    "z_k1_est",
    "level",
    "q_k1_est",
    "d",
    "name",
    "qk_est",
    "boot_id",
    "row_id",
    "col_id",
    "lty")
  )
